@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """CoRE Dataset."""
 import os
-from typing import Iterable, Optional, Tuple
+from typing import Collection, Optional, Tuple
 
 import numpy as np
 import pandas as pd
@@ -49,7 +49,6 @@ class CoREDataset(AbstractStructureDataset):
 
     The available labels are:
 
-
         * 'pure_CO2_kH': Henry coefficient of CO2 obtained by Widom method in mol kg-1 Pa-1
         * 'pure_CO2_widomHOA': Heat of adsorption of CO2 obtained by Widom method in
         * 'pure_methane_kH': Henry coefficient of methane obtained by Widom method in mol kg-1 Pa-1
@@ -84,7 +83,7 @@ class CoREDataset(AbstractStructureDataset):
         version: str = "v0.0.1",
         drop_basename_duplicates: bool = True,
         drop_graph_duplicates: bool = True,
-        subset: Optional[Iterable[int]] = None,
+        subset: Optional[Collection[int]] = None,
         drop_nan: bool = True,
     ):
         """Construct an instance of the CoRE dataset.
@@ -96,7 +95,7 @@ class CoREDataset(AbstractStructureDataset):
                 per CSD basename. Defaults to True.
             drop_graph_duplicates (bool): If True, keep only one structure
                 per decorated graph hash. Defaults to True.
-            subset (Iterable[int], optional): indices of the structures to include.
+            subset (Collection[int], optional): indices of the structures to include.
                 Defaults to None.
             drop_nan (bool): If True, drop rows with NaN values in features or hashes.
                 Defaults to True.
@@ -171,11 +170,11 @@ class CoREDataset(AbstractStructureDataset):
         self._featurenames = (c for c in self._df.columns if c.startswith("features."))
         self._infonames = (c for c in self._df.columns if c.startswith("info."))
 
-    def get_subset(self, indices: Iterable[int]) -> "AbstractStructureDataset":
+    def get_subset(self, indices: Collection[int]) -> "AbstractStructureDataset":
         """Get a subset of the dataset.
 
         Args:
-            indices (Iterable[int]): indices of the structures to include.
+            indices (Collection[int]): indices of the structures to include.
 
         Returns:
             AbstractStructureDataset: a new dataset containing only the structures
@@ -201,7 +200,7 @@ class CoREDataset(AbstractStructureDataset):
     def available_labels(self) -> Tuple[str]:
         return self._labelnames
 
-    def get_labels(self, idx: Iterable[int], labelnames: Iterable[str] = None) -> np.ndarray:
+    def get_labels(self, idx: Collection[int], labelnames: Collection[str] = None) -> np.ndarray:
         labelnames = labelnames if labelnames is not None else self._labelnames
         return self._df.iloc[idx][list(labelnames)].values
 
