@@ -1,16 +1,16 @@
 # -*- coding: utf-8 -*-
 """Interface for creating a custom StructureDataset."""
 from pathlib import Path
-from typing import Iterable, List, Optional
+from typing import Collection, List, Optional
 
 import numpy as np
 import pandas as pd
+from loguru import logger
 
 from mofdscribe.datasets.checks import check_all_file_exists
 from mofdscribe.datasets.dataset import AbstractStructureDataset
 from mofdscribe.datasets.utils import compress_dataset
 from mofdscribe.types import PathType
-from loguru import logger
 
 __all__ = ["StructureDataset", "FrameDataset"]
 
@@ -20,7 +20,7 @@ class StructureDataset(AbstractStructureDataset):
 
     def __init__(
         self,
-        files: Iterable[PathType],
+        files: Collection[PathType],
         df: Optional[pd.DataFrame] = None,
         structure_name_column: Optional[str] = None,
         year_column: Optional[str] = None,
@@ -35,7 +35,7 @@ class StructureDataset(AbstractStructureDataset):
         """Initialize a dataset.
 
         Args:
-            files (Iterable[PathType]): List of files to load structures from.
+            files (Collection[PathType]): List of files to load structures from.
             df (Optional[pd.DataFrame], optional): Dataframe containing the structures.
                 Defaults to None.
             structure_name_column (str): Name of the column containing the structure names.
@@ -71,8 +71,8 @@ class StructureDataset(AbstractStructureDataset):
         check_all_file_exists(self._structures)
 
         self._year_column = year_column
-        self._label_columns = list(label_columns) if label_columns is not None else tuple()
-        self._feature_columns = list(feature_columns) if feature_columns is not None else tuple()
+        self._label_columns = list(label_columns) if label_columns is not None else ()
+        self._feature_columns = list(feature_columns) if feature_columns is not None else ()
         self._decorated_graph_hash_column = decorated_graph_hash_column
         self._undecorated_graph_hash_column = undecorated_graph_hash_column
         self._decorated_scaffold_hash_column = decorated_scaffold_hash_column
@@ -115,7 +115,7 @@ class StructureDataset(AbstractStructureDataset):
     def available_labels(self) -> List[str]:
         return self._labelnames
 
-    def get_labels(self, idx: Iterable[int], labelnames: Iterable[str] = None) -> np.ndarray:
+    def get_labels(self, idx: Collection[int], labelnames: Collection[str] = None) -> np.ndarray:
         labelnames = labelnames if labelnames is not None else self._labelnames
         return self._df.iloc[idx][list(labelnames)].values
 
@@ -212,12 +212,14 @@ class FrameDataset(AbstractStructureDataset):
                 Defaults to None.
         """
         super().__init__()
-        logger.warning("FrameDataset support is experimental. Some splitter integrations may not work.")
+        logger.warning(
+            "FrameDataset support is experimental. Some splitter integrations may not work."
+        )
         self._df = df
         compress_dataset(self._df)
         self._structure_name_column = structure_name_column
         self._year_column = year_column
-        self._label_columns = list(label_columns) if label_columns is not None else tuple()
+        self._label_columns = list(label_columns) if label_columns is not None else ()
         self._decorated_graph_hash_column = decorated_graph_hash_column
         self._undecorated_graph_hash_column = undecorated_graph_hash_column
         self._decorated_scaffold_hash_column = decorated_scaffold_hash_column
@@ -252,6 +254,28 @@ class FrameDataset(AbstractStructureDataset):
         """Return number of structures in the dataset."""
         return len(self._df)
 
+    def get_subset(self, indices: Collection[int]) -> "FrameDataset":
+        """Get a subset of the dataset.
+
+        Args:
+            indices (Collection[int]): indices of the structures to include.
+
+        Returns:
+            FrameDataset: a new dataset containing only the structures
+                specified by the indices.
+        """
+        return FrameDataset(
+            self._df.iloc[indices],
+            structure_name_column=self._structure_name_column,
+            year_column=self._year_column,
+            label_columns=self._label_columns,
+            decorated_graph_hash_column=self._decorated_graph_hash_column,
+            undecorated_graph_hash_column=self._undecorated_graph_hash_column,
+            decorated_scaffold_hash_column=self._decorated_scaffold_hash_column,
+            undecorated_scaffold_hash_column=self._undecorated_scaffold_hash_column,
+            density_column=self._density_column,
+        )
+
     @property
     def available_features(self) -> List[str]:
         return self._featurenames
@@ -260,6 +284,6 @@ class FrameDataset(AbstractStructureDataset):
     def available_labels(self) -> List[str]:
         return self._labelnames
 
-    def get_labels(self, idx: Iterable[int], labelnames: Iterable[str] = None) -> np.ndarray:
+    def get_labels(self, idx: Collection[int], labelnames: Collection[str] = None) -> np.ndarray:
         labelnames = labelnames if labelnames is not None else self._labelnames
-        return self._df.iloc[idx][list(labelnames)].values
\ No newline at end of file
+        return self._df.iloc[idx][list(labelnames)].values
