@@ -5,6 +5,7 @@ import sys
 from shutil import which
 
 import numpy as np
+from pymatgen.core import Molecule, Structure
 
 if sys.version_info.major == 3 and sys.version_info.minor >= 10:
     from collections.abc import MutableMapping
@@ -39,3 +40,17 @@ def flatten(d: dict, parent_key: str = "", sep: str = ".") -> dict:
         else:
             items.append((new_key, v))
     return dict(items)
+
+
+def set_operates_on(self, featurizer):
+    try:
+        _operates_on = featurizer.operates_on()
+        if (Structure in _operates_on) and (Molecule in _operates_on):
+            self._operates_on = "both"
+        elif Structure in _operates_on:
+            self._operates_on = "structure"
+        elif Molecule in _operates_on:
+            self._operates_on = "molecule"
+
+    except AttributeError:
+        self._operates_on = "structure"
